@@ -8,7 +8,7 @@ no warnings 'recursion';
 
 package XML::Compile::Schema::BuiltInTypes;
 use vars '$VERSION';
-$VERSION = '1.23';
+$VERSION = '1.24';
 
 use base 'Exporter';
 
@@ -301,7 +301,7 @@ $builtin_types{base64Binary} =
 # (Use of) an XS implementation would be nice
 $builtin_types{hexBinary} =
  { parse   => sub { $_[0] =~ s/\s+//g; pack 'H*', $_[0]}
- , format  => sub { unpack 'H*', $_[0]}
+ , format  => sub { uc unpack 'H*', $_[0]}
  , check   =>
      sub { $_[0] !~ m/[^0-9a-fA-F\s]/ && (($_[0] =~ tr/0-9a-fA-F//) %2)==0}
  , example => 'F00F'
